@@ -15,37 +15,27 @@
 # MA  02111-1307  USA
 
 
-################################################################################
-# FUNCTION:                 DESCRIPTION:
-#  myUnits                   Sets date units
-################################################################################
-
-
 .RmetricsOptions <- new.env(hash = TRUE)
 
-
-# ------------------------------------------------------------------------------
-
-
-setRmetricsOptions <-
-    function(...)
+setRmetricsOptions <- function(...)
 {
     # A function implemented by Yohan Chalabi
 
     x <- list(...)
+    # check if argument was a single list
+    if (length(x) == 1 && is.list(x[[1]]))
+        x <- x[[1]]
     nm <- names(x)
      if (is.null(nm) || "" %in% nm)
         stop("all arguments must be named")
+    old <- lapply(nm, function(m) unname(getRmetricsOption(m)))
+    names(old) <- nm
     sapply(nm, function(nm) assign(nm, x[[nm]],
         envir = .RmetricsOptions))
-    invisible()
+    invisible(old)
 }
 
-
-# ------------------------------------------------------------------------------
-
-
-getRmetricsOption <-
+getRmetricsOptions <-
     function(x = NULL, unset = "")
 {
     # A function implemented by Yohan Chalabi
@@ -58,7 +48,11 @@ getRmetricsOption <-
 
 # YC : 2009-10-06
 # kept for compatibility purpose but should be eventually deprecated
-getRmetricsOptions <- getRmetricsOption
-
-################################################################################
-
+##
+## GNB : 2024-12-01
+##    :TODO:
+##    timeSeries v4041.111 has a call to getRmetricsOption(),
+##    which I have changed in the devel version to getRmetricsOptions().
+##    When that is published, I can remove getRmetricsOption().
+##    (after some time: users who update timeDate but not timeSeries would be in trouble)
+getRmetricsOption <- getRmetricsOptions
